==> pan-0.6.6.tar.bz2: pan-0.6.6/pan/message.h <==
/* Pan - Basic Message data structure
 *
 * Copyright (C) 1999 Jason Leach
 * Copyright (C) 1999 Matt Eagleson (e.Messiah@superpimp.org)
 *
 * Authors: Jason Leach <leach@wam.umd.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef __MESSAGE_H__
#define __MESSAGE_H__

typedef struct _Message Message;
typedef struct _MessageWindow MessageWindow;

typedef enum {
	NNTP_ARTICLE_READ,
	NNTP_ARTICLE_POST,
	NNTP_ARTICLE_REPLY,
//	EMAIL_READ,
//	EMAIL_POST,
//	EMAIL_REPLY,
	EMAIL_FORWARD
} MessageWindowType;

struct _Message {
	article_data *article;

	MessageWindowType type;
	MessageWindow *window;
	gboolean needs_window;

	gchar *to;
	gchar *from;
        gchar *newsgroups;
	gchar *organization;
	gchar *date;
	gchar *subject;
	gchar *body;
	gchar *references;

        gchar *reply_to;
        gchar *followup_to;

	gchar *message_id;
	gchar *full_text;
};


/*
==============================

  Function Prototypes

==============================
*/

Message* message_copy (Message *src);
void	 message_free (Message *msg);
Message* message_new (article_data *article);
void	 message_send (GtkWidget *widget, Message *msg);

void message_previous (GtkWidget *widget, Message *msg);
void message_next (GtkWidget *widget, Message *msg);

void message_import_adata (Message *msg, const article_data *adata);

#endif

==> pan-0.6.7.tar.bz2: pan-0.6.7/pan/message.h <==
/* Pan - Basic Message data structure
 *
 * Copyright (C) 1999 Jason Leach
 * Copyright (C) 1999 Matt Eagleson (e.Messiah@superpimp.org)
 *
 * Authors: Jason Leach <leach@wam.umd.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef __MESSAGE_H__
#define __MESSAGE_H__

typedef struct _Message Message;
typedef struct _MessageWindow MessageWindow;

typedef enum {
	NNTP_ARTICLE_READ,
	NNTP_ARTICLE_POST,
	NNTP_ARTICLE_REPLY,
//	EMAIL_READ,
//	EMAIL_POST,
//	EMAIL_REPLY,
	EMAIL_FORWARD
} MessageWindowType;

struct _Message {
	MessageWindowType type;
	MessageWindow *window;
	gboolean needs_window;

	gchar *to;
	gchar *from;
        gchar *newsgroups;
	gchar *organization;
	gchar *date;
	gchar *subject;
	gchar *body;
	gchar *references;

        gchar *reply_to;
        gchar *followup_to;

	gchar *message_id;
	gchar *full_text;
};


/*
==============================

  Function Prototypes

==============================
*/

Message* message_copy (const Message *src);
void	 message_free (Message *msg);
Message* message_new (article_data *article);
void	 message_send (GtkWidget *widget, Message *msg);

void message_previous (GtkWidget *widget, Message *msg);
void message_next (GtkWidget *widget, Message *msg);

void message_import_adata (Message *msg, const article_data *adata);

#endif
